<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>AppLauncher</name>
    <message>
        <location filename="../../src/tools/launcher/applaunchertool.cpp" line="40"/>
        <source>App Launcher</source>
        <translation>Spouštěč programů</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applaunchertool.cpp" line="52"/>
        <source>Choose an app to open the capture</source>
        <translation>Vyberte program pro otevření zachycené obrazovky</translation>
    </message>
</context>
<context>
    <name>AppLauncherWidget</name>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="56"/>
        <source>Open With</source>
        <translation>Otevřít s</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="71"/>
        <source>Launch in terminal</source>
        <translation>Spustit v terminálu</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="72"/>
        <source>Keep open after selection</source>
        <translation>Ponechat otevřené po výběru</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="109"/>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="124"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="109"/>
        <source>Unable to write in</source>
        <translation>Nelze zapsat</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/applauncherwidget.cpp" line="124"/>
        <source>Unable to launch in terminal.</source>
        <translation>Nelze spustit v terminálu.</translation>
    </message>
</context>
<context>
    <name>ArrowTool</name>
    <message>
        <location filename="../../src/tools/arrow/arrowtool.cpp" line="92"/>
        <source>Arrow</source>
        <translation>Šipka</translation>
    </message>
    <message>
        <location filename="../../src/tools/arrow/arrowtool.cpp" line="104"/>
        <source>Set the Arrow as the paint tool</source>
        <translation>Nastavit šipku jako malovací nástroj</translation>
    </message>
</context>
<context>
    <name>BlurTool</name>
    <message>
        <source>Blur</source>
        <translation type="vanished">Rozmazání</translation>
    </message>
    <message>
        <source>Set Blur as the paint tool</source>
        <translation type="vanished">Nastavit rozmazání jako malovací nástroj</translation>
    </message>
</context>
<context>
    <name>CaptureLauncher</name>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="67"/>
        <source>&lt;b&gt;Capture Mode&lt;/b&gt;</source>
        <translation>&lt;b&gt;Režim zachytávání&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="73"/>
        <source>Rectangular Region</source>
        <translation>Pravouhlá oblast</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="75"/>
        <source>Full Screen (All Monitors)</source>
        <translation>Celá obrazovka (všechny monitory)</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="83"/>
        <source>No Delay</source>
        <translation>Bez zpoždění</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="90"/>
        <source> second</source>
        <translation> sekunda</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="90"/>
        <source> seconds</source>
        <translation> sekund</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="94"/>
        <source>Take new screenshot</source>
        <translation>Zachytit nový snímek</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="103"/>
        <source>Area:</source>
        <translation>Oblast:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capturelauncher.cpp" line="104"/>
        <source>Delay:</source>
        <translation>Zpoždění:</translation>
    </message>
</context>
<context>
    <name>CaptureWidget</name>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="99"/>
        <source>Unable to capture screen</source>
        <translation>Nelze zachytit obrazovku</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="260"/>
        <source>Select an area with the mouse, or press Esc to exit.
Press Enter to capture the screen.
Press Right Click to show the color picker.
Use the Mouse Wheel to change the thickness of your tool.
Press Space to open the side panel.</source>
        <translation>Vyberte oblast myší nebo stiskněte Esc pro opuštění.
Stiskněte Enter pro zachycení obrazovky
Stiskněte pravé tlačítko myši pro zobrazení voliče barev.
Použijte kolečko myši pro změnu tloušťky nástroje.
Stiskněte mezerník pro otevření postranního panelu.</translation>
    </message>
    <message>
        <location filename="../../src/widgets/capture/capturewidget.cpp" line="617"/>
        <source>Tool Settings</source>
        <translation>Nastavení nástrojů</translation>
    </message>
</context>
<context>
    <name>CircleCountTool</name>
    <message>
        <location filename="../../src/tools/circlecount/circlecounttool.cpp" line="39"/>
        <source>Circle Counter</source>
        <translation>Kruhové počítadlo</translation>
    </message>
    <message>
        <location filename="../../src/tools/circlecount/circlecounttool.cpp" line="51"/>
        <source>Add an autoincrementing counter bubble</source>
        <translation>Přidá bublinu s číslem (vždy zvýšeným o jednotku)</translation>
    </message>
</context>
<context>
    <name>CircleTool</name>
    <message>
        <location filename="../../src/tools/circle/circletool.cpp" line="40"/>
        <source>Circle</source>
        <translation>Kruh</translation>
    </message>
    <message>
        <location filename="../../src/tools/circle/circletool.cpp" line="52"/>
        <source>Set the Circle as the paint tool</source>
        <translation>Nastavit kruh jako malovací nástroj</translation>
    </message>
</context>
<context>
    <name>ConfigWindow</name>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="43"/>
        <source>Configuration</source>
        <translation>Nastavení</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="63"/>
        <source>Interface</source>
        <translation>Rozhraní</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="69"/>
        <source>Filename Editor</source>
        <translation>Editor názvů souborů</translation>
    </message>
    <message>
        <location filename="../../src/config/configwindow.cpp" line="73"/>
        <source>General</source>
        <translation>Obecné</translation>
    </message>
</context>
<context>
    <name>Controller</name>
    <message>
        <location filename="../../src/core/controller.cpp" line="204"/>
        <source>&amp;Take Screenshot</source>
        <translation>&amp;Zachytit obrazovku</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="209"/>
        <source>&amp;Open Launcher</source>
        <translation>&amp;Otevřít spouštěč</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="212"/>
        <source>&amp;Configuration</source>
        <translation>&amp;Nastavení</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="215"/>
        <source>&amp;About</source>
        <translation>O &amp;programu</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation type="vanished">&amp;Informace</translation>
    </message>
    <message>
        <location filename="../../src/core/controller.cpp" line="217"/>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
</context>
<context>
    <name>CopyTool</name>
    <message>
        <location filename="../../src/tools/copy/copytool.cpp" line="41"/>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <location filename="../../src/tools/copy/copytool.cpp" line="53"/>
        <source>Copy the selection into the clipboard</source>
        <translation>Kopírovat výběr do schránky</translation>
    </message>
</context>
<context>
    <name>DBusUtils</name>
    <message>
        <location filename="../../src/utils/dbusutils.cpp" line="52"/>
        <source>Unable to connect via DBus</source>
        <translation>Nelze se spojit přes DBus</translation>
    </message>
</context>
<context>
    <name>ExitTool</name>
    <message>
        <location filename="../../src/tools/exit/exittool.cpp" line="40"/>
        <source>Exit</source>
        <translation>&amp;Opustit</translation>
    </message>
    <message>
        <location filename="../../src/tools/exit/exittool.cpp" line="52"/>
        <source>Leave the capture screen</source>
        <translation>Opustit zachytávací obrazovku</translation>
    </message>
</context>
<context>
    <name>FileNameEditor</name>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="39"/>
        <source>Edit the name of your captures:</source>
        <translation>Upravit název zachyceného:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="43"/>
        <source>Edit:</source>
        <translation>Upravit:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="45"/>
        <source>Preview:</source>
        <translation>Náhled:</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="88"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="91"/>
        <source>Saves the pattern</source>
        <translation>Uloží vzor</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="93"/>
        <source>Reset</source>
        <translation>Nastavit znovu</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="96"/>
        <source>Restores the saved pattern</source>
        <translation>Obnoví uložený vzor</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="98"/>
        <source>Clear</source>
        <translation>Vyprázdnit</translation>
    </message>
    <message>
        <location filename="../../src/config/filenameeditor.cpp" line="102"/>
        <source>Deletes the name</source>
        <translation>Smaže název</translation>
    </message>
</context>
<context>
    <name>GeneneralConf</name>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="121"/>
        <location filename="../../src/config/geneneralconf.cpp" line="258"/>
        <source>Import</source>
        <translation>Zavést</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="128"/>
        <location filename="../../src/config/geneneralconf.cpp" line="136"/>
        <location filename="../../src/config/geneneralconf.cpp" line="160"/>
        <location filename="../../src/config/geneneralconf.cpp" line="370"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="128"/>
        <source>Unable to read file.</source>
        <translation>Nelze přečíst soubor.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="136"/>
        <location filename="../../src/config/geneneralconf.cpp" line="160"/>
        <source>Unable to write file.</source>
        <translation>Nelze zapsat soubor.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="147"/>
        <source>Save File</source>
        <translation>Uložit soubor</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="170"/>
        <source>Confirm Reset</source>
        <translation>Potvrdit vrácení na výchozí</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="171"/>
        <source>Are you sure you want to reset the configuration?</source>
        <translation>Opravdu chcete nastavení vrátit do výchozího stavu?</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="181"/>
        <source>Show help message</source>
        <translation>Ukázat zprávu s nápovědou</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="185"/>
        <source>Show the help message at the beginning in the capture mode.</source>
        <translation>Ukázat zprávu s nápovědou na začátku v režimu zachytávání.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="196"/>
        <source>Show the side panel button</source>
        <translation>Ukázat tlačítko na postranním panelu</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="199"/>
        <source>Show the side panel toggle button in the capture mode.</source>
        <translation>V režimu zachytávání ukazovat tlačítko na postranním panelu.</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="210"/>
        <location filename="../../src/config/geneneralconf.cpp" line="214"/>
        <source>Show desktop notifications</source>
        <translation>Ukázat oznámení</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="227"/>
        <source>Show tray icon</source>
        <translation>Ukázat ikonu v oznamovací oblasti panelu</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="231"/>
        <source>Show the systemtray icon</source>
        <translation>Ukázat ikonu v oznamovací oblasti panelu</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="246"/>
        <source>Configuration File</source>
        <translation>Soubor s nastavením</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="251"/>
        <source>Export</source>
        <translation>Vyvést</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="265"/>
        <source>Reset</source>
        <translation>Nastavit znovu</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="276"/>
        <source>Launch at startup</source>
        <translation>Spustit při spuštění</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="280"/>
        <source>Launch Flameshot</source>
        <translation>Spustit Flameshot</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="290"/>
        <source>Close after capture</source>
        <translation>Zavřít po vytvoření snímku</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="294"/>
        <source>Close after taking a screenshot</source>
        <translation>Zavřít po vytvoření snímku obrazovky</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="306"/>
        <source>Copy URL after upload</source>
        <translation>Kopírovat adresu (URL) po nahrání</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="311"/>
        <source>Copy URL and close window after upload</source>
        <translation>Po nahrání zkopírovat URL a zavřít okno</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="322"/>
        <source>Save image after copy</source>
        <translation>Uložit obrázek po kopírování</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="323"/>
        <source>Save image file after copying it</source>
        <translation>Uložit obrázek se souborem po jeho zkopírování</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="332"/>
        <source>Save Path</source>
        <translation>Cesta pro ukládání</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="344"/>
        <source>Change...</source>
        <translation>Změnit...</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="363"/>
        <source>Choose a Folder</source>
        <translation>Vyberte složku</translation>
    </message>
    <message>
        <location filename="../../src/config/geneneralconf.cpp" line="370"/>
        <source>Unable to write to directory.</source>
        <translation>Nelze zapsat do adresáře.</translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="48"/>
        <source>Upload to Imgur</source>
        <translation>Nahrát do Imgur</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="55"/>
        <source>Uploading Image</source>
        <translation>Nahrává se obrázek</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="156"/>
        <source>Copy URL</source>
        <translation>Kopírovat adresu (URL)</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="157"/>
        <source>Open URL</source>
        <translation>Otevřít adresu (URL)</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="158"/>
        <source>Delete image</source>
        <translation>Smazat obrázek</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="159"/>
        <source>Image to Clipboard.</source>
        <translation>Obrázek do schránky.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="184"/>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="200"/>
        <source>Unable to open the URL.</source>
        <translation>Nelze otevřít adresu (URL).</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="192"/>
        <source>URL copied to clipboard.</source>
        <translation>Adresa (URL) zkopírována do schránky.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="208"/>
        <source>Screenshot copied to clipboard.</source>
        <translation>Snímek obrazovky zkopírován do schránky.</translation>
    </message>
</context>
<context>
    <name>ImgurUploaderTool</name>
    <message>
        <location filename="../../src/tools/imgur/imguruploadertool.cpp" line="41"/>
        <source>Image Uploader</source>
        <translation>Nahrávač obrázků</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploadertool.cpp" line="53"/>
        <source>Upload the selection to Imgur</source>
        <translation>Nahrát výběr do Imgur</translation>
    </message>
</context>
<context>
    <name>InfoWindow</name>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="40"/>
        <source>About</source>
        <translation>O programu</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="62"/>
        <source>SPACEBAR</source>
        <translation>MEZERNÍK</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="63"/>
        <source>Right Click</source>
        <translation>Klepnutí pravým tlačítkem myši</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="64"/>
        <source>Mouse Wheel</source>
        <translation>Kolečko myši</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="67"/>
        <source>Move selection 1px</source>
        <translation>Posunout výběr o 1 px</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="68"/>
        <source>Resize selection 1px</source>
        <translation>Změnit velikost výběru o 1 px</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="69"/>
        <source>Quit capture</source>
        <translation>Ukončit zachytávání obrazovky</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="70"/>
        <source>Copy to clipboard</source>
        <translation>Kopírovat do schránky</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="71"/>
        <source>Save selection as a file</source>
        <translation>Uložit výběr jako soubor</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="72"/>
        <source>Undo the last modification</source>
        <translation>Zrušit poslední změnu</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="73"/>
        <source>Toggle visibility of sidebar with options of the selected tool</source>
        <translation>Přepnout viditelnost postranního panelu s volbali pro vybraný nástroj</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="74"/>
        <source>Show color picker</source>
        <translation>Ukázat volič barev</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="75"/>
        <source>Change the tool&apos;s thickness</source>
        <translation>Změnit tloušťku nástroje</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="82"/>
        <source>Available shortcuts in the screen capture mode.</source>
        <translation>Dostupné zkratky v režimu zachytávání obrazovky.</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="93"/>
        <source>Key</source>
        <translation>Klávesa</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="93"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="126"/>
        <source>&lt;u&gt;&lt;b&gt;License&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;Licence&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="134"/>
        <source>&lt;u&gt;&lt;b&gt;Version&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;Verze&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
    <message>
        <location filename="../../src/widgets/infowindow.cpp" line="145"/>
        <source>&lt;u&gt;&lt;b&gt;Shortcuts&lt;/b&gt;&lt;/u&gt;</source>
        <translation>&lt;u&gt;&lt;b&gt;Zkratky&lt;/b&gt;&lt;/u&gt;</translation>
    </message>
</context>
<context>
    <name>LineTool</name>
    <message>
        <location filename="../../src/tools/line/linetool.cpp" line="43"/>
        <source>Line</source>
        <translation>Čára</translation>
    </message>
    <message>
        <location filename="../../src/tools/line/linetool.cpp" line="55"/>
        <source>Set the Line as the paint tool</source>
        <translation>Nastavit čáru jako malovací nástroj</translation>
    </message>
</context>
<context>
    <name>MarkerTool</name>
    <message>
        <location filename="../../src/tools/marker/markertool.cpp" line="43"/>
        <source>Marker</source>
        <translation>Zvýrazňovač</translation>
    </message>
    <message>
        <location filename="../../src/tools/marker/markertool.cpp" line="55"/>
        <source>Set the Marker as the paint tool</source>
        <translation>Nastavit zvýrazňovač jako malovací nástroj</translation>
    </message>
</context>
<context>
    <name>MoveTool</name>
    <message>
        <location filename="../../src/tools/move/movetool.cpp" line="40"/>
        <source>Move</source>
        <translation>Posunout</translation>
    </message>
    <message>
        <location filename="../../src/tools/move/movetool.cpp" line="52"/>
        <source>Move the selection area</source>
        <translation>Posunout oblast výběru</translation>
    </message>
</context>
<context>
    <name>PencilTool</name>
    <message>
        <location filename="../../src/tools/pencil/penciltool.cpp" line="34"/>
        <source>Pencil</source>
        <translation>Tužka</translation>
    </message>
    <message>
        <location filename="../../src/tools/pencil/penciltool.cpp" line="46"/>
        <source>Set the Pencil as the paint tool</source>
        <translation>Nastavit tužku jako malovací nástroj</translation>
    </message>
</context>
<context>
    <name>PinTool</name>
    <message>
        <location filename="../../src/tools/pin/pintool.cpp" line="40"/>
        <source>Pin Tool</source>
        <translation>Přišpendlení</translation>
    </message>
    <message>
        <location filename="../../src/tools/pin/pintool.cpp" line="52"/>
        <source>Pin image on the desktop</source>
        <translation>Přišpendlit obrázek na plochu</translation>
    </message>
</context>
<context>
    <name>PixelateTool</name>
    <message>
        <location filename="../../src/tools/pixelate/pixelatetool.cpp" line="40"/>
        <source>Pixelate</source>
        <translation>Rozčtverečkování</translation>
    </message>
    <message>
        <location filename="../../src/tools/pixelate/pixelatetool.cpp" line="52"/>
        <source>Set Pixelate as the paint tool</source>
        <translation>Nastaviť rozčtverečkování jako nástroj pro úpravy</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="112"/>
        <source>Save Error</source>
        <translation>Chyba při ukládání</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="66"/>
        <location filename="../../src/utils/screenshotsaver.cpp" line="107"/>
        <source>Capture saved as </source>
        <translation>Zachycená obrazovka uložena jako </translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="42"/>
        <source>Capture saved to clipboard.</source>
        <translation>Snímek uložen do schránky.</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="47"/>
        <source>Capture saved to clipboard</source>
        <translation>Zachycená obrazovka uložena do schránky</translation>
    </message>
    <message>
        <location filename="../../src/utils/screenshotsaver.cpp" line="69"/>
        <location filename="../../src/utils/screenshotsaver.cpp" line="110"/>
        <source>Error trying to save as </source>
        <translation>Chyba při ukládání jako </translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="82"/>
        <location filename="../../src/main.cpp" line="244"/>
        <location filename="../../src/main.cpp" line="399"/>
        <location filename="../../src/main.cpp" line="426"/>
        <location filename="../../src/main.cpp" line="458"/>
        <source>Unable to connect via DBus</source>
        <translation>Nelze se spojit přes DBus</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="104"/>
        <source>Powerful yet simple to use screenshot software.</source>
        <translation>Mocný, ale zároveň též jednoduchý program na zachytávání obrazovky.</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="105"/>
        <source>See</source>
        <translation>Podívejte se</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="108"/>
        <source>Capture the entire desktop.</source>
        <translation>Zachytit celou plochu.</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="110"/>
        <source>Open the capture launcher.</source>
        <translation>Otevřít spouštěč zachytávání.</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="112"/>
        <source>Start a manual capture in GUI mode.</source>
        <translation>Spustit ruční zachytávání v režimu uživatelského rozhraní.</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="114"/>
        <source>Configure</source>
        <translation>Nastavit</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="116"/>
        <source>Capture a single screen.</source>
        <translation>Zachytit jednu obrazovku.</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="120"/>
        <source>Path where the capture will be saved</source>
        <translation>Cesta, kam bude snímek uložen</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="123"/>
        <source>Save the capture to the clipboard</source>
        <translation>Uložit snímek do schránky</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="125"/>
        <source>Delay time in milliseconds</source>
        <translation>Čas zpoždění v milisekundách</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="128"/>
        <source>Set the filename pattern</source>
        <translation>Nastavit vzor pro pojmenování souborů</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="131"/>
        <source>Enable or disable the trayicon</source>
        <translation>Povolit nebo zakázat ikonu v oznamovací oblasti panelu</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="134"/>
        <source>Enable or disable run at startup</source>
        <translation>Povolit nebo zakázat spuštění při spuštění systému</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="138"/>
        <source>Show the help message in the capture mode</source>
        <translation>Ukazovat nápovědu v režimu zachytávání</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="141"/>
        <source>Define the main UI color</source>
        <translation>Nastavit barvu hlavního uživatelského rozhraní</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="144"/>
        <source>Define the contrast UI color</source>
        <translation>Nastavit kontrastní barvu uživatelského rozhraní</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="147"/>
        <source>Print raw PNG capture</source>
        <translation>Zobrazit nezpracovaný PNG snímek</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="150"/>
        <source>Define the screen to capture</source>
        <translation>Nastavit monitor, který bude zachytáván</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="151"/>
        <source>default: screen containing the cursor</source>
        <translation>výchozí: obrazovka, na které je ukazovátko myši</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="152"/>
        <source>Screen number</source>
        <translation>Číslo obrazovky</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="161"/>
        <source>Invalid color, this flag supports the following formats:
- #RGB (each of R, G, and B is a single hex digit)
- #RRGGBB
- #RRRGGGBBB
- #RRRRGGGGBBBB
- Named colors like &apos;blue&apos; or &apos;red&apos;
You may need to escape the &apos;#&apos; sign as in &apos;\#FFF&apos;</source>
        <translation>Neplatná barva, tento přepínač podporuje následující formáty:
- #RGB (každá ze složek R, G a B je samostatným hexadecimálním číslem)
- #RRGGBB
- #RRRGGGBBB
- #RRRRGGGGBBBB
- anglické názvy barev jako &apos;blue&apos; nebo &apos;red&apos;
Možná budete muset napsat před &apos;#&apos; opačné (obrácené) lomítko, tedy &apos;\#FFF&apos;</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="170"/>
        <source>Invalid delay, it must be higher than 0</source>
        <translation>Neplatné zpoždění, musí být vyšší než 0</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="172"/>
        <source>Invalid screen number, it must be non negative</source>
        <translation>Neplatné číslo obrazovky, může být jen kladné</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="179"/>
        <source>Invalid path, it must be a real path in the system</source>
        <translation>Neplatná cesta, musí se jednat o skutečnou cestu v systému</translation>
    </message>
    <message>
        <location filename="../../src/main.cpp" line="189"/>
        <source>Invalid value, it must be defined as &apos;true&apos; or &apos;false&apos;</source>
        <translation>Neplatná hodnota, musí být vymezenná jako &apos;pravda&apos; nebo &apos;nepravda&apos;</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/openwithprogram.cpp" line="45"/>
        <source>Error</source>
        <translation>Chyba</translation>
    </message>
    <message>
        <location filename="../../src/tools/launcher/openwithprogram.cpp" line="46"/>
        <source>Unable to write in</source>
        <translation>Nelze zapsat</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="64"/>
        <source>Options</source>
        <translation>Volby</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="77"/>
        <source>Arguments</source>
        <translation>Argumenty</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="350"/>
        <source>arguments</source>
        <translation>argumenty</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="351"/>
        <source>Usage</source>
        <translation>Použití</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="351"/>
        <source>options</source>
        <translation>volby</translation>
    </message>
    <message>
        <location filename="../../src/cli/commandlineparser.cpp" line="358"/>
        <source>Per default runs Flameshot in the background and   adds a tray icon for configuration.</source>
        <translation>Obvykle se Flameshot spouští na pozadí a přidává do oznamovací oblasti panelu ikonu, kterou je ho možné ovládat.</translation>
    </message>
    <message>
        <location filename="../../src/tools/imgur/imguruploader.cpp" line="88"/>
        <source>URL copied to clipboard.</source>
        <translation>Adresa (URL) zkopírována do schránky.</translation>
    </message>
</context>
<context>
    <name>RectangleTool</name>
    <message>
        <location filename="../../src/tools/rectangle/rectangletool.cpp" line="40"/>
        <source>Rectangle</source>
        <translation>Obdélník</translation>
    </message>
    <message>
        <location filename="../../src/tools/rectangle/rectangletool.cpp" line="52"/>
        <source>Set the Rectangle as the paint tool</source>
        <translation>Nastavit obdélník jako malovací nástroj</translation>
    </message>
</context>
<context>
    <name>RedoTool</name>
    <message>
        <location filename="../../src/tools/redo/redotool.cpp" line="40"/>
        <source>Redo</source>
        <translation>Znovu</translation>
    </message>
    <message>
        <location filename="../../src/tools/redo/redotool.cpp" line="52"/>
        <source>Redo the next modification</source>
        <translation>Znovu udělat další změnu</translation>
    </message>
</context>
<context>
    <name>SaveTool</name>
    <message>
        <location filename="../../src/tools/save/savetool.cpp" line="41"/>
        <source>Save</source>
        <translation>Uložit</translation>
    </message>
    <message>
        <location filename="../../src/tools/save/savetool.cpp" line="53"/>
        <source>Save the capture</source>
        <translation>Uložit zachycenou obrazovku</translation>
    </message>
</context>
<context>
    <name>ScreenGrabber</name>
    <message>
        <location filename="../../src/utils/screengrabber.cpp" line="84"/>
        <source>Unable to capture screen</source>
        <translation>Nelze zachytit obrazovku</translation>
    </message>
</context>
<context>
    <name>SelectionTool</name>
    <message>
        <location filename="../../src/tools/selection/selectiontool.cpp" line="46"/>
        <source>Rectangular Selection</source>
        <translation>Obdélníkový výběr</translation>
    </message>
    <message>
        <location filename="../../src/tools/selection/selectiontool.cpp" line="58"/>
        <source>Set Selection as the paint tool</source>
        <translation>Nastavit výběr jako malovací nástroj</translation>
    </message>
</context>
<context>
    <name>SidePanelWidget</name>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="72"/>
        <source>Active color:</source>
        <translation>Nynější barva:</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="217"/>
        <source>Press ESC to cancel</source>
        <translation>Stiskněte Esc pro zrušení</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="219"/>
        <source>Grab Color</source>
        <translation>Uchopit barvu</translation>
    </message>
    <message>
        <location filename="../../src/widgets/panel/sidepanelwidget.cpp" line="71"/>
        <source>Active thickness:</source>
        <translation>Nynější tloušťka:</translation>
    </message>
</context>
<context>
    <name>SizeIndicatorTool</name>
    <message>
        <location filename="../../src/tools/sizeindicator/sizeindicatortool.cpp" line="40"/>
        <source>Selection Size Indicator</source>
        <translation>Ukazatel velikosti výběru</translation>
    </message>
    <message>
        <location filename="../../src/tools/sizeindicator/sizeindicatortool.cpp" line="52"/>
        <source>Show the dimensions of the selection (X Y)</source>
        <translation>Ukázat rozměry výběru (X Y)</translation>
    </message>
</context>
<context>
    <name>StrftimeChooserWidget</name>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="50"/>
        <source>Century (00-99)</source>
        <translation>Století (00-99)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="51"/>
        <source>Year (00-99)</source>
        <translation>Rok (00-99)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="52"/>
        <source>Year (2000)</source>
        <translation>Rok (2000)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="53"/>
        <source>Month Name (jan)</source>
        <translation>Název měsíce (led)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="54"/>
        <source>Month Name (january)</source>
        <translation>Název měsíce (leden)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="55"/>
        <source>Month (01-12)</source>
        <translation>Měsíc (01-12)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="56"/>
        <source>Week Day (1-7)</source>
        <translation>Den v týdnu (1-7)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="57"/>
        <source>Week (01-53)</source>
        <translation>Týden (01-53)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="58"/>
        <source>Day Name (mon)</source>
        <translation>Název dne (pon)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="59"/>
        <source>Day Name (monday)</source>
        <translation>Název dne (pondělí)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="60"/>
        <source>Day (01-31)</source>
        <translation>Den (01-31)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="61"/>
        <source>Day of Month (1-31)</source>
        <translation>Den v měsíci (1-31)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="62"/>
        <source>Day (001-366)</source>
        <translation>Den v roce (001-366)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="63"/>
        <source>Time (%H-%M-%S)</source>
        <translation>Čas (%H-%M-%S)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="64"/>
        <source>Time (%H-%M)</source>
        <translation>Čas (%H-%M)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="65"/>
        <source>Hour (00-23)</source>
        <translation>Hodina (00-23)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="66"/>
        <source>Hour (01-12)</source>
        <translation>Hodina (01-12)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="67"/>
        <source>Minute (00-59)</source>
        <translation>Minuta (00-59)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="68"/>
        <source>Second (00-59)</source>
        <translation>Sekunda (00-59)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="69"/>
        <source>Full Date (%m/%d/%y)</source>
        <translation>Celé datum (%m/%d/%y)</translation>
    </message>
    <message>
        <location filename="../../src/config/strftimechooserwidget.cpp" line="70"/>
        <source>Full Date (%Y-%m-%d)</source>
        <translation>Celé datum (%Y-%m-%d)</translation>
    </message>
</context>
<context>
    <name>SystemNotification</name>
    <message>
        <location filename="../../src/utils/systemnotification.cpp" line="36"/>
        <source>Flameshot Info</source>
        <translation>Informace Flameshot</translation>
    </message>
</context>
<context>
    <name>TextConfig</name>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="54"/>
        <source>StrikeOut</source>
        <translation>Přeškrtnutí</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="63"/>
        <source>Underline</source>
        <translation>Podtržení</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="72"/>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/textconfig.cpp" line="81"/>
        <source>Italic</source>
        <translation>Kurzíva</translation>
    </message>
</context>
<context>
    <name>TextTool</name>
    <message>
        <location filename="../../src/tools/text/texttool.cpp" line="63"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location filename="../../src/tools/text/texttool.cpp" line="75"/>
        <source>Add text to your capture</source>
        <translation>Přidat text do zachyceného</translation>
    </message>
</context>
<context>
    <name>UIcolorEditor</name>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="32"/>
        <source>UI Color Editor</source>
        <translation>Editor barvy rozhraní</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="107"/>
        <source>Change the color moving the selectors and see the changes in the preview buttons.</source>
        <translation>Měňte barvu pohybováním voličů a dívejte se na změny v náhledových tlačítcích.</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="119"/>
        <source>Select a Button to modify it</source>
        <translation>Vybrat tlačítko pro jeho změnění</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="129"/>
        <source>Main Color</source>
        <translation>Hlavní barva</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="133"/>
        <source>Click on this button to set the edition mode of the main color.</source>
        <translation>Klepnout na toto tlačítko pro stanovení režimu upravení hlavní barvy.</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="144"/>
        <source>Contrast Color</source>
        <translation>Kontrastní barva</translation>
    </message>
    <message>
        <location filename="../../src/config/uicoloreditor.cpp" line="149"/>
        <source>Click on this button to set the edition mode of the contrast color.</source>
        <translation>Klepnout na toto tlačítko pro stanovení režimu upravení kontrastní barvy.</translation>
    </message>
</context>
<context>
    <name>UndoTool</name>
    <message>
        <location filename="../../src/tools/undo/undotool.cpp" line="40"/>
        <source>Undo</source>
        <translation>Zpět</translation>
    </message>
    <message>
        <location filename="../../src/tools/undo/undotool.cpp" line="52"/>
        <source>Undo the last modification</source>
        <translation>Zrušit poslední změnu</translation>
    </message>
</context>
<context>
    <name>UtilityPanel</name>
    <message>
        <location filename="../../src/widgets/panel/utilitypanel.cpp" line="114"/>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
</context>
<context>
    <name>VisualsEditor</name>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="61"/>
        <source>Opacity of area outside selection:</source>
        <translation>Neprůhlednost oblasti vně výběru:</translation>
    </message>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="89"/>
        <source>Button Selection</source>
        <translation>Tlačítko výběru</translation>
    </message>
    <message>
        <location filename="../../src/config/visualseditor.cpp" line="95"/>
        <source>Select All</source>
        <translation>Vybrat vše</translation>
    </message>
</context>
</TS>
